==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/SaveAs/ts/SaveAs_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>File Dialog</source>
        <translation>Datotečni vmesnik</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use system file dialog</source>
        <translation>Uporabi sistemski datotečni vmesnik</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Saving</source>
        <translation>Shranjevanje</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Default format:</source>
        <translation>Privzeti format:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translation>Prikaži opozorilo, ob shranjevanju v datotečni format, ki ne podpira 24bitne barve</translation>
    </message>
    <message>
        <location filename="../SaveAs.js" line="+38"/>
        <source>Load/Save</source>
        <translation>Naloži/Shrani</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="vanished">Shrani kot</translation>
    </message>
    <message>
        <source>No export filters</source>
        <translation type="vanished">Ni filtrov za izvoz</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>No export filters have been found. Aborting...</source>
        <translation>Ni bil najden noben filter. Prekinjam...</translation>
    </message>
    <message>
        <location line="+65"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translation>Shrani &amp;kot...</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/SaveAs/ts/SaveAs_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>SaveAs</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>File Dialog</source>
        <translation>Datotečni vmesnik</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Use system file dialog</source>
        <translation>Uporabi sistemski datotečni vmesnik</translation>
    </message>
    <message>
        <location line="+13"/>
        <source>Saving</source>
        <translation>Shranjevanje</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Default format:</source>
        <translation>Privzeti format:</translation>
    </message>
    <message>
        <location line="+37"/>
        <source>Show warning when saving to a file format that does not support 24bit colors</source>
        <translation>Prikaži opozorilo, ob shranjevanju v datotečni format, ki ne podpira 24bitne barve</translation>
    </message>
    <message>
        <source>Load/Save</source>
        <translation type="vanished">Naloži/Shrani</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="vanished">Shrani kot</translation>
    </message>
    <message>
        <source>No export filters</source>
        <translation type="vanished">Ni filtrov za izvoz</translation>
    </message>
    <message>
        <location filename="../SaveAs.js" line="+38"/>
        <source>File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Open/Save</source>
        <translation>Odpri/Shrani</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>No export filters have been found. Aborting...</source>
        <translation>Ni bil najden noben filter. Prekinjam...</translation>
    </message>
    <message>
        <location line="+74"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="../SaveAsInit.js" line="+2"/>
        <source>Save &amp;As...</source>
        <translation>Shrani &amp;kot...</translation>
    </message>
</context>
</TS>
